# RLBot

The RLBot framework helps people create bots for use in Rocket League's offline modes, just for fun.
It provides values from the game like car and ball position, and carries back button presses.
RLBot works for up to 10 bots.

To get started quickly with a simple working bot, you can clone this repository:
https://github.com/RLBot/RLBotPythonExample

### Requirements
Windows, Rocket League, Python 3.6+ (Python 3.7 recommended)

### Wikis

For more details, visit the [Setup guide](https://github.com/RLBot/RLBot/wiki/Setup-Instructions-%28current%29). When you're done, there are [more wikis](https://github.com/RLBot/RLBot/wiki) with additional information.

### Extras

#### Community Info
 - We have a [Discord server](https://discord.gg/zbaAKPt) (the heart of the community, please join!)
 - [We also have a subreddit.](https://www.reddit.com/r/RocketLeagueBots/)
 - We are now on v4 of RLBot so be wary of outdated information.
